[PATCH v2] eal/linux: skip attaching to external memory chunk

Deepak Khandelwal deepak.khandelwal at intel.com
Thu Apr 21 11:11:21 CEST 2022


Currently, EAL init in secondary processes will attach all fbarrays
in the memconfig to have access to primary process' page tables.
However, fbarrays corresponding to external memory segments should
not be attached at initialization, because this will happen as part
of `rte_extmem_attach` or `rte_malloc_heap_memory_attach` calls.

Both external memory API's document this:

rte_malloc:
http://doc.dpdk.org/api/rte__malloc_8h.html#af6360dea35bdf162feeb2b62cf149fd3

rte_extmem:
http://doc.dpdk.org/api/rte__memory_8h.html#a2796da68de6825f8edf53759f8e4d230

Fixes: ff3619d6244b ("malloc: allow attaching to external memory chunks")
Cc: stable at dpdk.org

Signed-off-by: Deepak Khandelwal <deepak.khandelwal at intel.com>
Suggested-by: Anatoly Burakov <anatoly.burakov at intel.com>
Acked-by: Anatoly Burakov <anatoly.burakov at intel.com>

---
v2:
* commit message updated and handle for BSD
---
 lib/eal/freebsd/eal_memory.c | 4 ++--
 lib/eal/linux/eal_memory.c   | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/lib/eal/freebsd/eal_memory.c b/lib/eal/freebsd/eal_memory.c
index 78ac142..17ab10e 100644
--- a/lib/eal/freebsd/eal_memory.c
+++ b/lib/eal/freebsd/eal_memory.c
@@ -446,8 +446,8 @@ struct attach_walk_args {
 
 		msl = &mcfg->memsegs[msl_idx];
 
-		/* skip empty memseg lists */
-		if (msl->memseg_arr.len == 0)
+		/* skip empty and external memseg lists */
+		if (msl->memseg_arr.len == 0 || msl->external)
 			continue;
 
 		if (rte_fbarray_attach(&msl->memseg_arr)) {
diff --git a/lib/eal/linux/eal_memory.c b/lib/eal/linux/eal_memory.c
index ee1a9e6..c890c42 100644
--- a/lib/eal/linux/eal_memory.c
+++ b/lib/eal/linux/eal_memory.c
@@ -1874,8 +1874,8 @@ void numa_error(char *where)
 
 		msl = &mcfg->memsegs[msl_idx];
 
-		/* skip empty memseg lists */
-		if (msl->memseg_arr.len == 0)
+		/* skip empty and external memseg lists */
+		if (msl->memseg_arr.len == 0 || msl->external)
 			continue;
 
 		if (rte_fbarray_attach(&msl->memseg_arr)) {
-- 
1.8.3.1



More information about the stable mailing list